ebenezer.widgets package
========================

Submodules
----------

ebenezer.widgets.app\_menu module
---------------------------------

.. automodule:: ebenezer.widgets.app_menu
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.arrow module
-----------------------------

.. automodule:: ebenezer.widgets.arrow
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.backlight module
---------------------------------

.. automodule:: ebenezer.widgets.backlight
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.bar module
---------------------------

.. automodule:: ebenezer.widgets.bar
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.battery module
-------------------------------

.. automodule:: ebenezer.widgets.battery
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.clock module
-----------------------------

.. automodule:: ebenezer.widgets.clock
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.cpu module
---------------------------

.. automodule:: ebenezer.widgets.cpu
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.formatter module
---------------------------------

.. automodule:: ebenezer.widgets.formatter
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.github module
------------------------------

.. automodule:: ebenezer.widgets.github
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.group\_box module
----------------------------------

.. automodule:: ebenezer.widgets.group_box
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.hidden\_tray module
------------------------------------

.. automodule:: ebenezer.widgets.hidden_tray
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.layout module
------------------------------

.. automodule:: ebenezer.widgets.layout
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.lock\_screen module
------------------------------------

.. automodule:: ebenezer.widgets.lock_screen
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.logo module
----------------------------

.. automodule:: ebenezer.widgets.logo
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.memory module
------------------------------

.. automodule:: ebenezer.widgets.memory
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.notification module
------------------------------------

.. automodule:: ebenezer.widgets.notification
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.powermenu module
---------------------------------

.. automodule:: ebenezer.widgets.powermenu
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.spacer module
------------------------------

.. automodule:: ebenezer.widgets.spacer
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.task\_list module
----------------------------------

.. automodule:: ebenezer.widgets.task_list
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.thermal module
-------------------------------

.. automodule:: ebenezer.widgets.thermal
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.volume module
------------------------------

.. automodule:: ebenezer.widgets.volume
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.wallpaper module
---------------------------------

.. automodule:: ebenezer.widgets.wallpaper
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.weather module
-------------------------------

.. automodule:: ebenezer.widgets.weather
   :members:
   :undoc-members:
   :show-inheritance:

ebenezer.widgets.window\_name module
------------------------------------

.. automodule:: ebenezer.widgets.window_name
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ebenezer.widgets
   :members:
   :undoc-members:
   :show-inheritance:
